//+------------------------------------------------------------------+
//|                             RSI_HalfMirror_HalfRegular_30min.mq4 |
//|                                     Copyright  2011, zequikups. |
//|                                                             none |
//+------------------------------------------------------------------+
// This indicator mixes the regular RSI with a part of RSI_Mirror, concretely the OPEN PRICE - CLOSE part. 
// It shows 2 lines in the indi window + arrows in the chart. Line crosses are signals. 
// Its is optimized for TF 1h with RSIPeriod = 2, according to streetlight's indications
// Added Arrows function
#property copyright "zequikups"
#property link      "me"

#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 100
#property indicator_level1 20
#property indicator_level2 50
#property indicator_level3 80
#property indicator_buffers 4
#property indicator_color1 Lime
#property indicator_color2 Orange
#property indicator_color3 White
#property indicator_color4 Red
#property indicator_width1 2
#property indicator_width4 2
//---- input parameters
extern int RSIPeriod=2;
extern string ARROW_SETTINGS = "ARROW SETTINGS";
extern bool DrawArrows = true;
extern color UpCross = Red;
extern color DownCross = Lime;
extern double PercentMargin = 0.0; //0,05 default value
extern int ArrowCode1 = 233; 
extern int ArrowCode2 = 234;
extern bool reversal = true;  
//---- buffers
double RSIBuffer[];  //Original RSI calculation
double PosBuffer[];
double NegBuffer[];
double RSIBuffer2[];  //RSI form RSI_Mirror, according to open price...



// Optimized for 30 min TF



void DrawArrow( int bar , double value , int trend)
   {
      
      static int cnt = 0;
      cnt++;
      string crossing = "CROSSING_" + cnt;
      string label = "LABEL" + cnt;

      ObjectCreate(crossing, OBJ_ARROW, 0, Time[bar+1], value);
      
      if(reversal==false)
      {
         if (trend == 1) trend = 2;
         else if (trend == 2) trend = 1;
      }
      
      if(trend == 1)
      {
         ObjectSet(crossing, OBJPROP_ARROWCODE, ArrowCode2);
         ObjectSet(crossing, OBJPROP_COLOR , UpCross);
      }
      
      if(trend == 2)
      {
         ObjectSet(crossing, OBJPROP_ARROWCODE, ArrowCode1);
         ObjectSet(crossing, OBJPROP_COLOR , DownCross);

      }

      ObjectSet(crossing, OBJPROP_WIDTH  , 1);
      ObjectsRedraw();  
   }


int Crossed1 (double line1 , double line2)  //LEma, SEma
   {
      static int last_direction;
      static int current_direction = 0;
      
      //Don't work in the first load, wait for the first cross!
      //static bool first_time = true;
      //if(first_time == true)
      //{
      //   first_time = false;
      //   return (0);
      //}
      
      if(line1>line2 && ((line1-line2) > ((line1*PercentMargin) / 100)))current_direction = 1; //short
      if(line1<line2 && ((line2-line1) > ((line1*PercentMargin) / 100)))current_direction = 2; //long

      if(current_direction != last_direction) //changed 
      {
            last_direction = current_direction;
            return (last_direction);
      }
      else
      {
            return (0); //not changed
      }
   }
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   //string short_name;
//---- 2 additional buffers are used for counting.
   
   IndicatorDigits(Digits);
   IndicatorBuffers(4);
   SetIndexBuffer(1,PosBuffer);
   SetIndexBuffer(2,NegBuffer);
//---- indicator line
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,RSIBuffer);
   SetIndexStyle(3,DRAW_LINE);
   SetIndexBuffer(3,RSIBuffer2);
//---- name for DataWindow and indicator subwindow label
   //short_name="RSI("+RSIPeriod+")";
   //IndicatorShortName(short_name);
   SetIndexLabel(0,"REGULAR RSI");
   SetIndexLabel(3,"MIRROR RSI / OPEN-CLOSE PRICE");
//----
   SetIndexDrawBegin(0,RSIPeriod);
   SetIndexDrawBegin(3,RSIPeriod);
//----
   return(0);
  }

//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- 
   //Delete all the drawn objects!
   int I = WindowsTotal();
   for (int count = 0; count < WindowsTotal(); count++)
   {
      ObjectsDeleteAll(count, OBJ_ARROW);
      ObjectsDeleteAll(count, OBJ_TEXT);
   
   }
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Relative Strength Index                                          |
//+------------------------------------------------------------------+
int start()
  {
   int    i,counted_bars=IndicatorCounted();
   double rel,negative,positive;
   int CurrentisCrossed = 0;
   static int LASTCurrentisCrossed;
//----
   if(Bars<=RSIPeriod) return(0);
//---- initial zero
   if(counted_bars<1)
      for(i=1;i<=RSIPeriod;i++) RSIBuffer[Bars-i]=0.0;
//----
   i=Bars-RSIPeriod-1;
   if(counted_bars>=RSIPeriod) i=Bars-counted_bars-1;
   while(i>=0)
     {
      double sumn=0.0,sump=0.0;
      if(i==Bars-RSIPeriod-1)
        {
         int k=Bars-2;
         //---- initial accumulation
         while(k>=i)
           {
            rel=Close[k]-Close[k+1];
            if(rel>0) sump+=rel;
            else      sumn-=rel;
            k--;
           }
         positive=sump/RSIPeriod;
         negative=sumn/RSIPeriod;
        }
      else
        {
         //---- smoothed moving average
         rel=Close[i]-Close[i+1];
         if(rel>0) sump=rel;
         else      sumn=-rel;
         positive=(PosBuffer[i+1]*(RSIPeriod-1)+sump)/RSIPeriod;
         negative=(NegBuffer[i+1]*(RSIPeriod-1)+sumn)/RSIPeriod;
        }
      PosBuffer[i]=positive;
      NegBuffer[i]=negative;
      if(negative==0.0) RSIBuffer[i]=0.0;
      else RSIBuffer[i]=100.0-100.0/(1+positive/negative);
      
      //for(i=0; i<limit; i++)
      RSIBuffer2[i]=(iRSI(NULL, 0, RSIPeriod, PRICE_OPEN, i)- iRSI(NULL, 0, RSIPeriod, PRICE_CLOSE, i))+ 50;
      
      if (DrawArrows)
         {
         CurrentisCrossed = Crossed1 (RSIBuffer2[i],RSIBuffer[i]);
            if(CurrentisCrossed > 0)
            {
               if(CurrentisCrossed != LASTCurrentisCrossed)
               {
                  LASTCurrentisCrossed = CurrentisCrossed;
                  
                  if (LASTCurrentisCrossed == 2) DrawArrow (i  , Low[i] , LASTCurrentisCrossed);
                  else
                     {
                     if (LASTCurrentisCrossed == 1) DrawArrow (i  , High[i] , LASTCurrentisCrossed);
                     }
               }
               
            }
         }
              
      IndicatorShortName("RSI_HalfMirror_HalfRegular_30min - RSIPeriod "+RSIPeriod);
      i--;
      CurrentisCrossed = 0;
     }
//----
   return(0);
  }
//+------------------------------------------------------------------+